from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.db import models


@python_2_unicode_compatible
class ElectionVote(models.Model):
    """ """
    id = models.AutoField(_("id"), primary_key=True)
    election_id = models.IntegerField(
        _("election id"), db_index=True,
        default=-1, editable=False)
    empty_entry = models.BooleanField(
        _("empty entry"), default=False)
    ciphered_vote = models.TextField(
        _("ciphered vote"), default='')
    blind_components = models.TextField(
        _("blind components"), default='')
    pr_components = models.TextField(
        _("pRcomponents"), default='')
    signed_vote_hash = models.TextField(
        _("signed vote hash"), default='')
    deciphered_vote = models.TextField(
        _("deciphered vote"), default='')
    decipher_timestamp = models.DateTimeField(
        _("deciphered vote date"),
        null=True,
        editable=False,
        blank=True)

    class Meta:
        verbose_name = _("Election vote")
        verbose_name_plural = _("Election votes")
        index_together = ['election_id', 'id']

    def __str__(self):
        return self.signed_vote_hash


@python_2_unicode_compatible
class UniqueVote(models.Model):
    """ """
    id = models.AutoField(_("id"), primary_key=True)
    election_id = models.IntegerField(
        _("election id"), db_index=True,
        default=-1, editable=False)
    unique_vote_bulletin = models.CharField(
        _("unique vote bulletin"), max_length=512,
        db_index=True, default='', editable=False)
    empty_entry = models.BooleanField(
        _("empty entry"), default=False)

    class Meta:
        verbose_name = _("Unique election vote")
        verbose_name_plural = _("Unique election votes")
        index_together = ['election_id', 'id']

    def __str__(self):
        return self.unique_vote_bulletin
